==> slang_retail_assistant-8.1.0.tar.gz: lib/src/assistant_ui.dart <==
part of slang_retail_assistant;

enum BaseMode { LIGHT, DARK }

class _AssistantUI {
  MethodChannel? _channel;

  _AssistantUI(MethodChannel methodChannel) {
    this._channel = methodChannel;
  }

  void expandTrigger() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("expandTrigger");
  }

  void collapseTrigger() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("collapseTrigger");
  }

  void showTrigger() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("showTrigger");
  }

  void hideTrigger() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("hideTrigger");
  }

  void setMode(BaseMode mode) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setMode", {"mode": mode.toString()});
  }

  void disableLocaleSelection(bool disable) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("disableLocaleSelection", {"disable": disable});
  }

  void nudgeUser(Map<String, String> title, Map<String, String> description) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod(
        "nudgeUser", {"title": title, "description": description});
  }

  void setForegroundColorGradient(List colors) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setForegroundColorGradient", {"colors", colors});
  }

  void setBackgroundColorGradient(List colors) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setBackgroundColorGradient", {"colors", colors});
  }

  void setWaveVelocity(double velocity) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setWaveVelocity", {"color", velocity});
  }

  void setTriggerSize(int width, int height) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod(
        "setForegroundColorGradient", {"width": width, "height": height});
  }

  void setTextColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setTextColor", {"color": color});
  }

  void setSecondaryTextColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setSecondaryTextColor", {"color": color});
  }

  void setSettingsButtonBackgroundColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel
        ?.invokeMapMethod("setSettingsButtonBackgroundColor", {"color": color});
  }

  void setControlButtonBackgroundColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel
        ?.invokeMapMethod("setControlButtonBackgroundColor", {"color": color});
  }

  void setTextHighlightColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setTextHighlightColor", {"color": color});
  }

  void setTriggerImageResource(String path) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    rootBundle.load(path).then((imageData) {
      var imageArray = imageData.buffer.asUint8List();
      _channel?.invokeMethod("setTriggerImageResource", imageArray);
    }).whenComplete(() {});
  }
}

==> slang_retail_assistant-8.7.0.tar.gz: lib/src/assistant_ui.dart <==
part of slang_retail_assistant;

enum BaseMode { LIGHT, DARK }

class _AssistantUI {
  MethodChannel? _channel;

  _AssistantUI(MethodChannel methodChannel) {
    this._channel = methodChannel;
  }

  void expandTrigger() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("expandTrigger");
  }

  void collapseTrigger() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("collapseTrigger");
  }

  void showTrigger() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("showTrigger");
  }

  void hideTrigger() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("hideTrigger");
  }

  void setMode(BaseMode mode) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setMode", {"mode": mode.toString()});
  }

  void disableLocaleSelection(bool disable) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("disableLocaleSelection", {"disable": disable});
  }

  void nudgeUser() {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMethod("nudgeUser");
  }

  void customNudgeUser(
      Map<String, String> title, Map<String, String> description) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod(
        "customNudgeUser", {"title": title, "description": description});
  }

  void setForegroundColorGradient(List colors) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setForegroundColorGradient", {"colors", colors});
  }

  void setBackgroundColorGradient(List colors) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setBackgroundColorGradient", {"colors", colors});
  }

  void setWaveVelocity(double velocity) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setWaveVelocity", {"color", velocity});
  }

  void setTriggerSize(int width, int height) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod(
        "setForegroundColorGradient", {"width": width, "height": height});
  }

  void setTextColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setTextColor", {"color": color});
  }

  void setSecondaryTextColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setSecondaryTextColor", {"color": color});
  }

  void setSettingsButtonBackgroundColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel
        ?.invokeMapMethod("setSettingsButtonBackgroundColor", {"color": color});
  }

  void setControlButtonBackgroundColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel
        ?.invokeMapMethod("setControlButtonBackgroundColor", {"color": color});
  }

  void setTextHighlightColor(String color) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    _channel?.invokeMapMethod("setTextHighlightColor", {"color": color});
  }

  void setTriggerImageResource(String path) {
    if (!SlangRetailAssistant._validateEnvironment()) {
      return;
    }
    rootBundle.load(path).then((imageData) {
      var imageArray = imageData.buffer.asUint8List();
      _channel?.invokeMethod("setTriggerImageResource", imageArray);
    }).whenComplete(() {});
  }
}
